@@ -33,13 +33,13 @@
 #include <spi/spi.h>
 
 static struct at91_ether_platform_data ether_pdata = {
-	.is_rmii = 1,
+	.phy_interface = PHY_INTERFACE_MODE_RMII,
 	.phy_addr = 0,
 };
 
 static int at91rm9200ek_mem_init(void)
 {
-	at91_add_device_sdram(32 * 1024 * 1024);
+	at91_add_device_sdram(0);
 
 	return 0;
 }
