@@ -10,31 +10,21 @@
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- *
  */
 
 #include <common.h>
-#include <net.h>
 #include <init.h>
 #include <environment.h>
-#include <fec.h>
 #include <asm/armlinux.h>
 #include <generated/mach-types.h>
-#include <partition.h>
-#include <fs.h>
-#include <fcntl.h>
-#include <io.h>
-#include <asm/hardware.h>
 #include <nand.h>
 #include <sizes.h>
-#include <linux/mtd/nand.h>
 #include <mach/board.h>
 #include <mach/at91sam9_smc.h>
 #include <gpio.h>
 #include <mach/io.h>
-#include <mach/at91_pmc.h>
 #include <mach/at91_rstc.h>
+#include <linux/clk.h>
 
 /*
  * board revision encoding
@@ -47,9 +37,8 @@ static void ek_set_board_type(void)
 {
 	if (machine_is_at91sam9g20ek()) {
 		armlinux_set_architecture(MACH_TYPE_AT91SAM9G20EK);
-#ifdef CONFIG_AT91_HAVE_2MMC
-		armlinux_set_revision(HAVE_2MMC);
-#endif
+		if (IS_ENABLED(CONFIG_AT91_HAVE_2MMC))
+			armlinux_set_revision(HAVE_2MMC);
 	} else {
 		armlinux_set_architecture(MACH_TYPE_AT91SAM9260EK);
 	}
@@ -61,11 +50,6 @@ static struct atmel_nand_data nand_pdata = {
 	.det_pin	= -EINVAL,
 	.rdy_pin	= AT91_PIN_PC13,
 	.enable_pin	= AT91_PIN_PC14,
-#if defined(CONFIG_MTD_NAND_ATMEL_BUSWIDTH_16)
-	.bus_width_16	= 1,
-#else
-	.bus_width_16	= 0,
-#endif
 	.on_flash_bbt	= 1,
 };
 
@@ -83,7 +67,8 @@ static struct sam9_smc_config ek_9260_nand_smc_config = {
 	.read_cycle		= 5,
 	.write_cycle		= 5,
 
-	.mode			= AT91_SMC_READMODE | AT91_SMC_WRITEMODE | AT91_SMC_EXNWMODE_DISABLE,
+	.mode			= AT91_SMC_READMODE | AT91_SMC_WRITEMODE |
+				  AT91_SMC_EXNWMODE_DISABLE,
 	.tdf_cycles		= 2,
 };
 
@@ -101,7 +86,8 @@ static struct sam9_smc_config ek_9g20_nand_smc_config = {
 	.read_cycle		= 7,
 	.write_cycle		= 7,
 
-	.mode			= AT91_SMC_READMODE | AT91_SMC_WRITEMODE | AT91_SMC_EXNWMODE_DISABLE,
+	.mode			= AT91_SMC_READMODE | AT91_SMC_WRITEMODE |
+				  AT91_SMC_EXNWMODE_DISABLE,
 	.tdf_cycles		= 3,
 };
 
@@ -115,10 +101,12 @@ static void ek_add_device_nand(void)
 		smc = &ek_9260_nand_smc_config;
 
 	/* setup bus-width (8 or 16) */
-	if (nand_pdata.bus_width_16)
+	if (IS_ENABLED(CONFIG_MTD_NAND_ATMEL_BUSWIDTH_16)) {
+		nand_pdata.bus_width_16 = 1;
 		smc->mode |= AT91_SMC_DBW_16;
-	else
+	} else {
 		smc->mode |= AT91_SMC_DBW_8;
+	}
 
 	/* configure chip-select 3 (NAND) */
 	sam9_smc_configure(0, 3, smc);
@@ -134,7 +122,9 @@ static struct at91_ether_platform_data macb_pdata = {
 static void at91sam9260ek_phy_reset(void)
 {
 	unsigned long rstc;
-	at91_pmc_write(AT91_PMC_PCER, 1 << AT91SAM9260_ID_EMAC);
+	struct clk *clk = clk_get(NULL, "macb_clk");
+
+	clk_enable(clk);
 
 	at91_set_gpio_input(AT91_PIN_PA14, 0);
 	at91_set_gpio_input(AT91_PIN_PA15, 0);
@@ -153,18 +143,16 @@ static void at91sam9260ek_phy_reset(void)
 	at91_sys_write(AT91_RSTC_CR, AT91_RSTC_KEY | AT91_RSTC_EXTRST);
 
 	/* Wait for end hardware reset */
-	while (!(at91_sys_read(AT91_RSTC_SR) & AT91_RSTC_NRSTL));
+	while (!(at91_sys_read(AT91_RSTC_SR) & AT91_RSTC_NRSTL))
+		;
 
 	/* Restore NRST value */
-	at91_sys_write(AT91_RSTC_MR, AT91_RSTC_KEY |
-				     (rstc) |
-				     AT91_RSTC_URSTEN);
+	at91_sys_write(AT91_RSTC_MR, AT91_RSTC_KEY | (rstc) | AT91_RSTC_URSTEN);
 }
 
 /*
  * MCI (SD/MMC)
  */
-#if defined(CONFIG_MCI_ATMEL)
 static struct atmel_mci_platform_data __initdata ek_mci_data = {
 	.bus_width	= 4,
 	.slot_b		= 1,
@@ -174,14 +162,14 @@ static struct atmel_mci_platform_data __initdata ek_mci_data = {
 
 static void ek_usb_add_device_mci(void)
 {
+	if (!IS_ENABLED(CONFIG_MCI_ATMEL))
+		return;
+
 	if (machine_is_at91sam9g20ek())
 		ek_mci_data.detect_pin = AT91_PIN_PC9;
 
 	at91_add_device_mci(0, &ek_mci_data);
 }
-#else
-static void ek_usb_add_device_mci(void) {}
-#endif
 
 /*
  * USB Host port
@@ -218,10 +206,10 @@ static void __init ek_add_led(void)
 {
 	int i;
 
-#ifdef CONFIG_AT91_HAVE_2MMC
-	leds[0].gpio = AT91_PIN_PB8;
-	leds[1].gpio = AT91_PIN_PB9;
-#endif
+	if (IS_ENABLED(CONFIG_AT91_HAVE_2MMC)) {
+		leds[0].gpio = AT91_PIN_PB8;
+		leds[1].gpio = AT91_PIN_PB9;
+	}
 
 	for (i = 0; i < ARRAY_SIZE(leds); i++) {
 		at91_set_gpio_output(leds[i].gpio, leds[i].active_low);
@@ -273,7 +261,6 @@ static int at91sam9260ek_devices_init(void)
 
 	return 0;
 }
-
 device_initcall(at91sam9260ek_devices_init);
 
 static int at91sam9260ek_console_init(void)
@@ -281,5 +268,4 @@ static int at91sam9260ek_console_init(void)
 	at91_register_uart(0, 0);
 	return 0;
 }
-
 console_initcall(at91sam9260ek_console_init);
