@@ -15,7 +15,10 @@
 #include <init.h>
 #include <io.h>
 #include <linux/mtd/nand.h>
+#include <asm/sections.h>
+#include <asm/barebox-arm.h>
 #include <mach/imx-nand.h>
+#include <mach/esdctl.h>
 #include <mach/generic.h>
 #include <mach/imx21-regs.h>
 #include <mach/imx25-regs.h>
@@ -256,6 +259,124 @@ void __bare_init imx_nand_load_image(void *dest, int size)
 	}
 }
 
+/*
+ * This function assumes the currently running binary has been
+ * copied from its current position to an offset. It returns
+ * to the calling function - offset.
+ * NOTE: The calling function may not return itself since it still
+ * works on the old content of the lr register. Only call this
+ * from a __noreturn function.
+ */
+static __bare_init __naked void jump_sdram(unsigned long offset)
+{
+	__asm__ __volatile__ (
+			"sub lr, lr, %0;"
+			"mov pc, lr;" : : "r"(offset)
+			);
+}
+
+/*
+ * Load and start barebox from NAND. This function also checks if we are really
+ * running inside the NFC address space. If not, barebox is started from the
+ * currently running address without loading anything from NAND.
+ */
+int __bare_init imx_barebox_boot_nand_external(unsigned long nfc_base)
+{
+	u32 r;
+	u32 *src, *trg;
+	int i;
+
+	/* skip NAND boot if not running from NFC space */
+	r = get_pc();
+	if (r < nfc_base || r > nfc_base + 0x800)
+		return 0;
+
+	src = (unsigned int *)nfc_base;
+	trg = (unsigned int *)_text;
+
+	/* Move ourselves out of NFC SRAM */
+	for (i = 0; i < 0x800 / sizeof(int); i++)
+		*trg++ = *src++;
+
+	return 1;
+}
+
+/*
+ * SoC specific entries for booting in external NAND mode. To be called from
+ * the board specific entry code. This is safe to call even if not booting from
+ * NAND. In this case the booting is continued without loading an image from
+ * NAND. This function needs a stack to be set up.
+ */
+#ifdef CONFIG_ARCH_IMX21
+void __bare_init __noreturn imx21_barebox_boot_nand_external(void)
+{
+	unsigned long nfc_base = MX21_NFC_BASE_ADDR;
+
+	if (imx_barebox_boot_nand_external(nfc_base)) {
+		jump_sdram(nfc_base - (unsigned long)_text);
+		imx_nand_load_image((void *)_text, barebox_image_size);
+	}
+
+	imx21_barebox_entry(0);
+}
+#endif
+
+#ifdef CONFIG_ARCH_IMX25
+void __bare_init __noreturn imx25_barebox_boot_nand_external(void)
+{
+	unsigned long nfc_base = MX25_NFC_BASE_ADDR;
+
+	if (imx_barebox_boot_nand_external(nfc_base)) {
+		jump_sdram(nfc_base - (unsigned long)_text);
+		imx_nand_load_image((void *)_text, barebox_image_size);
+	}
+
+	imx25_barebox_entry(0);
+}
+#endif
+
+#ifdef CONFIG_ARCH_IMX27
+void __bare_init __noreturn imx27_barebox_boot_nand_external(void)
+{
+	unsigned long nfc_base = MX27_NFC_BASE_ADDR;
+
+	if (imx_barebox_boot_nand_external(nfc_base)) {
+		jump_sdram(nfc_base - (unsigned long)_text);
+		imx_nand_load_image((void *)_text, barebox_image_size);
+	}
+
+	imx27_barebox_entry(0);
+}
+#endif
+
+#ifdef CONFIG_ARCH_IMX31
+void __bare_init __noreturn imx31_barebox_boot_nand_external(void)
+{
+	unsigned long nfc_base = MX31_NFC_BASE_ADDR;
+
+	if (imx_barebox_boot_nand_external(nfc_base)) {
+		jump_sdram(nfc_base - (unsigned long)_text);
+		imx_nand_load_image((void *)_text, barebox_image_size);
+	}
+
+	imx31_barebox_entry(0);
+}
+#endif
+
+#ifdef CONFIG_ARCH_IMX35
+void __bare_init __noreturn imx35_barebox_boot_nand_external(void)
+{
+	unsigned long nfc_base = MX35_NFC_BASE_ADDR;
+
+	if (imx_barebox_boot_nand_external(nfc_base)) {
+		jump_sdram(nfc_base - (unsigned long)_text);
+		imx_nand_load_image((void *)_text, barebox_image_size);
+	}
+
+	imx35_barebox_entry(0);
+}
+#endif
+
 #define CONFIG_NAND_IMX_BOOT_DEBUG
 #ifdef CONFIG_NAND_IMX_BOOT_DEBUG
 #include <command.h>
