@@ -23,9 +23,9 @@
 #include <mach/omap3-silicon.h>
 
 #ifdef CONFIG_OMAP3EVM_UART1
-#define UART_BASE	OMAP_UART1_BASE
+#define UART_BASE	OMAP3_UART1_BASE
 #else
-#define UART_BASE	OMAP_UART3_BASE
+#define UART_BASE	OMAP3_UART3_BASE
 #endif
 
 #endif
@@ -35,6 +35,11 @@
 #define UART_BASE	OMAP44XX_UART3_BASE
 #endif
 
+#ifdef CONFIG_ARCH_AM33XX
+#include <mach/am33xx-silicon.h>
+#define UART_BASE	AM33XX_UART0_BASE
+#endif
+
 #define LSR_THRE	0x20	/* Xmit holding register empty */
 #define LSR		(5 << 2)
 #define THR		(0 << 2)
