@@ -1,8 +1,9 @@
 #include <common.h>
 #include <io.h>
 #include <mach/syslib.h>
-#include <mach/silicon.h>
+#include <mach/omap4-silicon.h>
 #include <mach/clocks.h>
+#include <mach/omap4-clock.h>
 
 #define LDELAY	12000000
 
