@@ -385,14 +385,21 @@ static int ahci_init_port(struct ahci_port *ahci_port)
 	ahci_port_info(ahci_port, "Spinning up device...\n");
 
 	ret = wait_on_timeout(WAIT_SPINUP,
-			(readl(port_mmio + PORT_TFDATA) &
-			 (ATA_STATUS_BUSY | ATA_STATUS_DRQ)) == 0);
+			((readl(port_mmio + PORT_TFDATA) &
+			 (ATA_STATUS_BUSY | ATA_STATUS_DRQ)) == 0)
+			|| !((readl(port_mmio + PORT_SCR_STAT) & 0xf) == 1));
 	if (ret) {
 		ahci_port_info(ahci_port, "timeout.\n");
 		ret = -ENODEV;
 		goto err_init;
 	}
 
+	if ((readl(port_mmio + PORT_SCR_STAT) & 0xf) == 1) {
+		ahci_port_info(ahci_port, "down.\n");
+		ret = -ENODEV;
+		goto err_init;
+	}
+
 	ahci_port_info(ahci_port, "ok.\n");
 
 	val = ahci_port_read(ahci_port, PORT_SCR_ERR);
@@ -664,15 +671,18 @@ static int ahci_probe(struct device_d *dev)
 	return ret;
 }
 
+static __maybe_unused struct of_device_id ahci_dt_ids[] = {
+	{
+		.compatible = "calxeda,hb-ahci",
+	}, {
+		/* sentinel */
+	}
+};
+
 static struct driver_d ahci_driver = {
 	.name   = "ahci",
 	.probe  = ahci_probe,
 	.info	= ahci_info,
+	.of_compatible = DRV_OF_COMPAT(ahci_dt_ids),
 };
-
-static int ahci_init(void)
-{
-	return platform_driver_register(&ahci_driver);
-}
-
-device_initcall(ahci_init);
+device_platform_driver(ahci_driver);
