@@ -524,12 +524,4 @@ static struct driver_d mxcmci_driver = {
         .name  = DRIVER_NAME,
         .probe = mxcmci_probe,
 };
-
-static int mxcmci_init_driver(void)
-{
-        platform_driver_register(&mxcmci_driver);
-        return 0;
-}
-
-device_initcall(mxcmci_init_driver);
-
+device_platform_driver(mxcmci_driver);
