@@ -62,16 +62,7 @@ int mtd_all_ff(const void *buf, unsigned int len)
 	return 1;
 }
 
-int mtd_block_isbad(struct mtd_info *mtd, loff_t ofs)
-{
-	if (!mtd->block_isbad)
-		return 0;
-	if (ofs < 0 || ofs > mtd->size)
-		return -EINVAL;
-	return mtd->block_isbad(mtd, ofs);
-}
-
-static 	ssize_t mtd_read(struct cdev *cdev, void* buf, size_t count,
+static ssize_t mtd_op_read(struct cdev *cdev, void* buf, size_t count,
 			  loff_t _offset, ulong flags)
 {
 	struct mtd_info *mtd = cdev->priv;
@@ -79,9 +70,10 @@ static 	ssize_t mtd_read(struct cdev *cdev, void* buf, size_t count,
 	int ret;
 	unsigned long offset = _offset;
 
-	debug("mtd_read: 0x%08lx 0x%08x\n", offset, count);
+	dev_dbg(cdev->dev, "read ofs: 0x%08lx count: 0x%08x\n",
+			offset, count);
 
-	ret = mtd->read(mtd, offset, count, &retlen, buf);
+	ret = mtd_read(mtd, offset, count, &retlen, buf);
 
 	if(ret) {
 		printf("err %d\n", ret);
@@ -94,19 +86,19 @@ static 	ssize_t mtd_read(struct cdev *cdev, void* buf, size_t count,
 #define MTDPGALG(x) ((x) & ~(mtd->writesize - 1))
 
 #ifdef CONFIG_MTD_WRITE
-static ssize_t mtd_write(struct cdev* cdev, const void *buf, size_t _count,
+static ssize_t mtd_op_write(struct cdev* cdev, const void *buf, size_t _count,
 			  loff_t _offset, ulong flags)
 {
 	struct mtd_info *mtd = cdev->priv;
 	size_t retlen;
 	int ret;
 
-	ret = mtd->write(mtd, _offset, _count, &retlen, buf);
+	ret = mtd_write(mtd, _offset, _count, &retlen, buf);
 
 	return ret ? ret : _count;
 }
 
-static int mtd_erase(struct cdev *cdev, size_t count, loff_t offset)
+static int mtd_op_erase(struct cdev *cdev, size_t count, loff_t offset)
 {
 	struct mtd_info *mtd = cdev->priv;
 	struct erase_info erase;
@@ -124,7 +116,7 @@ static int mtd_erase(struct cdev *cdev, size_t count, loff_t offset)
 		if (ret > 0) {
 			printf("Skipping bad block at 0x%08x\n", erase.addr);
 		} else {
-			ret = mtd->erase(mtd, &erase);
+			ret = mtd_erase(mtd, &erase);
 			if (ret)
 				return ret;
 		}
@@ -135,6 +127,20 @@ static int mtd_erase(struct cdev *cdev, size_t count, loff_t offset)
 
 	return 0;
 }
+
+static ssize_t mtd_op_protect(struct cdev *cdev, size_t count, loff_t offset, int prot)
+{
+	struct mtd_info *mtd = cdev->priv;
+
+	if (!mtd->unlock || !mtd->lock)
+		return -ENOSYS;
+
+	if (prot)
+		return mtd_lock(mtd, offset, count);
+	else
+		return mtd_unlock(mtd, offset, count);
+}
+
 #endif /* CONFIG_MTD_WRITE */
 
 int mtd_ioctl(struct cdev *cdev, int request, void *buf)
@@ -159,10 +165,10 @@ int mtd_ioctl(struct cdev *cdev, int request, void *buf)
 #ifdef CONFIG_MTD_WRITE
 	case MEMSETBADBLOCK:
 		dev_dbg(cdev->dev, "MEMSETBADBLOCK: 0x%08llx\n", *offset);
-		ret = mtd->block_markbad(mtd, *offset);
+		ret = mtd_block_markbad(mtd, *offset);
 		break;
 	case MEMERASE:
-		ret = mtd_erase(cdev, ei->length, ei->start + cdev->offset);
+		ret = mtd_op_erase(cdev, ei->length, ei->start + cdev->offset);
 		break;
 #endif
 	case MEMGETINFO:
@@ -201,11 +207,74 @@ int mtd_ioctl(struct cdev *cdev, int request, void *buf)
 	return ret;
 }
 
+int mtd_lock(struct mtd_info *mtd, loff_t ofs, uint64_t len)
+{
+	if (!mtd->lock)
+		return -EOPNOTSUPP;
+	if (ofs < 0 || ofs > mtd->size || len > mtd->size - ofs)
+		return -EINVAL;
+	if (!len)
+		return 0;
+	return mtd->lock(mtd, ofs, len);
+}
+
+int mtd_unlock(struct mtd_info *mtd, loff_t ofs, uint64_t len)
+{
+	if (!mtd->unlock)
+		return -EOPNOTSUPP;
+	if (ofs < 0 || ofs > mtd->size || len > mtd->size - ofs)
+		return -EINVAL;
+	if (!len)
+		return 0;
+	return mtd->unlock(mtd, ofs, len);
+}
+
+int mtd_block_isbad(struct mtd_info *mtd, loff_t ofs)
+{
+	if (!mtd->block_isbad)
+		return 0;
+
+	if (ofs < 0 || ofs > mtd->size)
+		return -EINVAL;
+
+	return mtd->block_isbad(mtd, ofs);
+}
+
+int mtd_block_markbad(struct mtd_info *mtd, loff_t ofs)
+{
+	int ret;
+
+	if (mtd->block_markbad)
+		ret = mtd->block_markbad(mtd, ofs);
+	else
+		ret = -ENOSYS;
+
+	return ret;
+}
+
+int mtd_read(struct mtd_info *mtd, loff_t from, size_t len, size_t *retlen,
+		u_char *buf)
+{
+	return mtd->read(mtd, from, len, retlen, buf);
+}
+
+int mtd_write(struct mtd_info *mtd, loff_t to, size_t len, size_t *retlen,
+		const u_char *buf)
+{
+	return mtd->write(mtd, to, len, retlen, buf);
+}
+
+int mtd_erase(struct mtd_info *mtd, struct erase_info *instr)
+{
+	return mtd->erase(mtd, instr);
+}
+
 static struct file_operations mtd_ops = {
-	.read   = mtd_read,
+	.read   = mtd_op_read,
 #ifdef CONFIG_MTD_WRITE
-	.write  = mtd_write,
-	.erase  = mtd_erase,
+	.write  = mtd_op_write,
+	.erase  = mtd_op_erase,
+	.protect = mtd_op_protect,
 #endif
 	.ioctl  = mtd_ioctl,
 	.lseek  = dev_lseek_default,
