@@ -86,7 +86,7 @@ static int fec_miibus_read(struct mii_bus *bus, int phyAddr, int regAddr)
 	start = get_time_ns();
 	while (!(readl(fec->regs + FEC_IEVENT) & FEC_IEVENT_MII)) {
 		if (is_timeout(start, MSECOND)) {
-			printf("Read MDIO failed...\n");
+			dev_err(&fec->edev.dev, "Read MDIO failed...\n");
 			return -1;
 		}
 	}
@@ -126,7 +126,7 @@ static int fec_miibus_write(struct mii_bus *bus, int phyAddr,
 	start = get_time_ns();
 	while (!(readl(fec->regs + FEC_IEVENT) & FEC_IEVENT_MII)) {
 		if (is_timeout(start, MSECOND)) {
-			printf("Write MDIO failed...\n");
+			dev_err(&fec->edev.dev, "Write MDIO failed...\n");
 			return -1;
 		}
 	}
@@ -361,12 +361,18 @@ static int fec_init(struct eth_device *dev)
 static void fec_update_linkspeed(struct eth_device *edev)
 {
 	struct fec_priv *fec = (struct fec_priv *)edev->priv;
+	int speed = edev->phydev->speed;
+	u32 rcntl = readl(fec->regs + FEC_R_CNTRL) & ~FEC_R_CNTRL_RMII_10T;
+	u32 ecntl = readl(fec->regs + FEC_ECNTRL) & ~FEC_ECNTRL_SPEED;
 
-	if (edev->phydev->speed == SPEED_10) {
-		u32 rcntl = readl(fec->regs + FEC_R_CNTRL);
+	if (speed == SPEED_10)
 		rcntl |= FEC_R_CNTRL_RMII_10T;
-		writel(rcntl, fec->regs + FEC_R_CNTRL);
-	}
+
+	if (speed == SPEED_1000)
+		ecntl |= FEC_ECNTRL_SPEED;
+
+	writel(rcntl, fec->regs + FEC_R_CNTRL);
+	writel(ecntl, fec->regs + FEC_ECNTRL);
 }
 
 /**
@@ -425,15 +431,20 @@ static int fec_open(struct eth_device *edev)
 static void fec_halt(struct eth_device *dev)
 {
 	struct fec_priv *fec = (struct fec_priv *)dev->priv;
-	int counter = 0xffff;
+	uint64_t tmo;
 
 	/* issue graceful stop command to the FEC transmitter if necessary */
 	writel(readl(fec->regs + FEC_X_CNTRL) | FEC_ECNTRL_RESET,
 			fec->regs + FEC_X_CNTRL);
 
 	/* wait for graceful stop to register */
-	while ((counter--) && (!(readl(fec->regs + FEC_IEVENT) & FEC_IEVENT_GRA)))
-		;	/* FIXME ensure time */
+	tmo = get_time_ns();
+	while (!(readl(fec->regs + FEC_IEVENT) & FEC_IEVENT_GRA)) {
+		if (is_timeout(tmo, 1 * SECOND)) {
+			dev_err(&dev->dev, "graceful stop timeout\n");
+			break;
+		}
+	}
 
 	/* Disable SmartDMA tasks */
 	fec_tx_task_disable(fec);
@@ -468,12 +479,12 @@ static int fec_send(struct eth_device *dev, void *eth_data, int data_length)
 
 	/* Check for valid length of data. */
 	if ((data_length > 1500) || (data_length <= 0)) {
-		printf("Payload (%d) to large!\n", data_length);
+		dev_err(&dev->dev, "Payload (%d) to large!\n", data_length);
 		return -1;
 	}
 
 	if ((uint32_t)eth_data & (DB_DATA_ALIGNMENT-1))
-		printf("%s: Warning: Transmit data not aligned: %p!\n", __FUNCTION__, eth_data);
+		dev_warn(&dev->dev, "Transmit data not aligned: %p!\n", eth_data);
 
 	/*
 	 * Setup the transmit buffer
@@ -506,7 +517,7 @@ static int fec_send(struct eth_device *dev, void *eth_data, int data_length)
 	tmo = get_time_ns();
 	while (readw(&fec->tbd_base[fec->tbd_index].status) & FEC_TBD_READY) {
 		if (is_timeout(tmo, 1 * SECOND)) {
-			printf("transmission timeout\n");
+			dev_err(&dev->dev, "transmission timeout\n");
 			break;
 		}
 	}
@@ -544,7 +555,7 @@ static int fec_recv(struct eth_device *dev)
 		/* BABT, Rx/Tx FIFO errors */
 		fec_halt(dev);
 		fec_init(dev);
-		printf("some error: 0x%08x\n", ievent);
+		dev_err(&dev->dev, "some error: 0x%08x\n", ievent);
 		return 0;
 	}
 	if (!fec_is_imx28(fec)) {
@@ -587,7 +598,7 @@ static int fec_recv(struct eth_device *dev)
 			len = frame_length;
 		} else {
 			if (bd_status & FEC_RBD_ERR) {
-				printf("error frame: 0x%p 0x%08x\n", rbd, bd_status);
+				dev_warn(&dev->dev, "error frame: 0x%p 0x%08x\n", rbd, bd_status);
 			}
 		}
 		/*
@@ -768,14 +779,7 @@ static struct driver_d fec_driver = {
 	.of_compatible = DRV_OF_COMPAT(imx_fec_dt_ids),
 	.id_table = imx_fec_ids,
 };
-
-static int fec_register(void)
-{
-	platform_driver_register(&fec_driver);
-	return 0;
-}
-
-device_initcall(fec_register);
+device_platform_driver(fec_driver);
 
 /**
  * @file
